# Pywalfox - Native messaging host

This is the native application used by the Pywalfox addon providing it with access to your pywal colors. It uses the [Native Messaging API](https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/Native_messaging).

**You should not use this version with the addon. This is a rewrite of the current daemon. Eventually, the daemon will be removed from the current [repository](https://github.com/Frewacom/Pywalfox) and replaced with this one. When this happens, the daemon will also be available to download from your package manager (either pip or the Arch AUR).**
